@@ -21,7 +21,7 @@ static void case_execit (char const *const *argv, char const *expr, char const *
   if (n)
   {
     size_t exprlen = strlen(expr) ;
-    size_t fmtlen = exprlen + 6 ;
+    size_t fmtlen = exprlen + 6 + uint_fmt(0, n-1) ;
     for (size_t i = 1 ; i < n ; i++)
       fmtlen += uint_fmt(0, i) + 2 + pmatch[i].rm_eo - pmatch[i].rm_so ;
     {
@@ -111,7 +111,7 @@ int main (int argc, char const **argv, char const *const *envp)
         memcpy(tmp + 1, expr, len) ;
         tmp[1+len] = '$' ;
         tmp[2+len] = 0 ;
-        r = regcomp(&re, tmp, (flagextended ? REG_EXTENDED : 0) | (flagicase ? REG_ICASE : 0) | (flagnosub ? REG_NOSUB : 0) | REG_NEWLINE) ;
+        r = regcomp(&re, tmp, (flagextended ? REG_EXTENDED : 0) | (flagicase ? REG_ICASE : 0) | (flagnosub ? REG_NOSUB : 0)) ;
         if (r)
         {
           char buf[256] ;
